*** govindv.do
local v = "2.6"
*** 17 Aug 2010
***
*** "Industry Effects of Government Spending"
*** By Chris Nekarda and Valerie Ramey
***
*** Description:
***
*** Requires:
***     govindustry-v2.3.dta (main data set)
***     agg-gov.dta (aggregate government data)
***     eta-ind.dta (time-varying coefficients for marignal markup, created by eta-ind.do)
***     eedata-sic2-q-sa.dta (CES 2-digit employment and hours data)
***
***************************************************************************************************
clear all
set more off
capture log close
log using govind-v`v'.log, text replace
set linesize 120

noisily display as text "$S_DATE $S_TIME  govind.do (v`v')"

set memory 100m
set matsize 400

use govindustry-v2.3.dta
* SIC 3673 does not exist before 1984
drop if sic4==3673

sort year
merge year using agg-gov.dta, nokeep
tab _merge
drop _merge
tsset sic4 year, y

*************************************************
***             MARKUP MEASURES               ***
*************************************************

** Regression of v/h on h in CES data
preserve
use eedata-sic2-q-sa.dta, replace
keep if qdate>=tq(1960q1) & qdate<=tq(2002q4)
gen vh = v/h
capture confirm mat coef
if _rc==0 mat drop coef
local estlist = ""
capture confirm file tab-tvar-ind.tex
if _rc==0 erase tab-tvar-ind.tex
forvalues i = 20/39 {
    eststo v`i': reg vh h if sic2==`i'
    mat coef = [nullmat(coef) \ e(b)]
    local estlist = "`estlist' v`i'"
    esttab v`i' using tab-tvar-ind.tex, b(%04.3f) se r2 star(* 0.10 ** 0.05 *** 0.01) noobs order(_cons h) wide nopar width(\textwidth) nolabel booktabs alignment(d{1.3}) frag append
}
* note: matrix coef (20 x 2) has elements [h _cons]
restore
*
** Create marginal/average wage factors
* merge in industry etas
sort sic2 year
merge sic2 year using eta-ind.dta
drop _merge
tsset sic4 year, y
* create factors
gen bcons = .
gen bH = .
local j 0
forvalues i = 20/39 {
    local j=`++j'
    qui replace bcons = coef[`j',2] if sic2==`i'
    qui replace bH = coef[`j',1] if sic2    ==`i'
}
gen wmwap25 = (1 + .25*eta)/(1 + .50*(bcons + bH*hp))
gen wmwap50 = (1 + .50*eta)/(1 + .50*(bcons + bH*hp))
gen wmwat25 = (1 + .25*eta)/(1 + .50*(bcons + bH*ht))
gen wmwat50 = (1 + .50*eta)/(1 + .50*(bcons + bH*ht))
*
format wmwa* %05.4f
sum wmwap25 wmwap50 wmwat25 wmwat50, f sep(2)
drop bcons bH

*** DEFINE MARKUPS
*long-run average labor share
egen alphap= mean(payp/vship), by(sic4)
egen alphat= mean(payt/vship), by(sic4)
* average wage markup, gross output
gen lymup = ln(alphap*xpy/rwp)
gen lymut = ln(alphat*xty/rwt)
* marginal wage markup, gross output
gen lymumg25p = ln(alphap*xpy/(rwp*wmwap25))
gen lymumg50p = ln(alphap*xpy/(rwp*wmwap50))
gen lymumg25t = ln(alphat*xty/(rwt*wmwat25))
gen lymumg50t = ln(alphat*xty/(rwt*wmwat50))
* price cost margin (DHP, 1986)
gen pcm = (vship+D.invent-payt-matcost)/(vship+D.invent)
* calculate annual changes
foreach var in lymup lymumg50p pcm {
    gen d`var' = 100*D.`var'
}


*************************************************
***        VARIABLES FOR REGRESSIONS          ***
*************************************************

** CALCULATE LOG AND ANNUAL LOG CHANGE
foreach var in Ht Hp Hs Nt Np Ns hp ht nwp nwt rwp rwt rvship y xpy k piship rmatxe renergy rfed l_rfed f_rfed {
    gen l`var' = ln(`var')
    gen dl`var' = 100*D.l`var'
}

** CALCULATE ANNUALIZED FIVE-YEAR LOG CHANGE
foreach var in y xpy {
    by sic4: gen d5l`var' = 100*(l`var' - L5.l`var')/5
    by sic4: replace d5l`var' = 100*(l`var' - L4.l`var')/4 if year==1967
}

** SHARE-WEIGHTED INPUTS USING AVERAGE SHARES
* average nominal shares
egen se_avg = mean(energy/vship), by(sic4)
egen smx_avg = mean((matcost - energy)/vship), by(sic4)
egen sl_avg = mean(payt_ch/vship), by(sic4)
* capital share is residual
gen sk_avg = 1 - smx_avg - se_avg - sl_avg
* share-weighted inputs
gen dlinput =  sk_avg*dlk + sl_avg*dlHt + smx_avg*dlrmatxe + se_avg*dlrenergy
label var dlinput "Share-weighted log change in inputs"

*************************************************
***        DEFINITION OF INSTRUMENTS          ***
*************************************************

** TIME AVERAGE SHARE OF SHIPMENTS TO GOVERNMENT (theta_i)
egen theta_i = mean(gtotal/vshipio), by(sic4)

** INITIAL VALUE OF SHIPMENTS TO GOVERNMENT (theta_1963)
gen foo = gtotal/vshipio if year==1963
* sic 3052 and 3845 did not exist in 1963. using first available value
replace foo = .04425009 if sic4==3052 & year==1963
replace foo = .01376675 if sic4==3845 & year==1963
* create for all observations
egen theta_1963 = max(foo), by(sic4)
drop foo

*** PEROTTI'S INSTRUMENT
** Perotti's definition
gen d5rgper = (rgtotal - L5.rgtotal)/(5*L5.rvshipio)
replace d5rgper = (rgtotal - L4.rgtotal)/(4*L4.rvshipio) if year==1967

** \bar{phi}_i and \bar{S}_i
gen rgtotal_agg = gtotal_agg/pfed
gen lrgtot_agg = ln(rgtotal_agg)
gen phi_it = rgtotal/rgtotal_agg
egen phi_i = mean(phi_it), by(sic4)
egen S_i = mean(rvshipio), by(sic4)

** Perotti w/ purged numerator
gen d5rgnum = phi_i*(rgtotal_agg - L5.rgtotal_agg)/(5*L5.rvshipio)
replace d5rgnum = phi_i*(rgtotal_agg - L4.rgtotal_agg)/(4*L4.rvshipio) if year==1967

** Perotti w/ purged numerator and denominator
gen d5rgnumden = phi_i*(rgtotal_agg - L5.rgtotal_agg)/(5*S_i)
replace d5rgnumden = phi_i*(rgtotal_agg - L4.rgtotal_agg)/(4*S_i) if year==1967

*** NEKARDA-RAMEY (NR) INSTRUMENT
** 5-yr NR w/ IO measure of government shipments and average share used as weight
by sic4: gen d5rgnr1 = theta_i*(lrgtot_agg - L5.lrgtot_agg)/5
by sic4: replace d5rgnr1 = theta_i*(lrgtot_agg - L4.lrgtot_agg)/4 if year==1967
*
** 5-yr NR w/ NIPA measure of government shipments and average share used as weight
by sic4: gen d5rgnr2 = theta_i*(lrfed - L5.lrfed)/5
by sic4: replace d5rgnr2 = theta_i*(lrfed - L4.lrfed)/4 if year==1967
*
** 5-yr NR w/ NIPA measure of government shipments and 1963 share used as weight
by sic4: gen d5rgnr3 = theta_1963*(lrfed - L5.lrfed)/5
by sic4: replace d5rgnr3 = theta_1963*(lrfed - L4.lrfed)/4 if year==1967
*
** 1-yr NR w/ log change in aggregate federal spending by theta_i
gen dgnr = theta_i*dlrfed
gen ldgnr = theta_i*dll_rfed
gen fdgnr = theta_i*dlf_rfed
*
** 1-yr NR w/ log change in aggregate federal spending by theta_1963
gen dgnr63 = theta_1963*dlrfed

** Standardize instruments to compare coefficients
foreach var in d5rgper d5rgnum d5rgnumden d5rgnr1 d5rgnr2 d5rgnr3 {
    capture sum `var' if d5rgper!=.
    qui replace `var' = `var'/r(sd)
}
** Create standardized NR annual variables for table 2 only
capture sum dgnr if tin(1958,1992)
gen dgnr_std = dgnr/r(sd)
capture sum dgnr63 if tin(1958,1992)
gen dgnr63_std = dgnr/r(sd)

*** BREAK C4 AND UR_PROD INTO TERCILES
egen c4_avg = mean(c4), by(sic4)
egen urp_avg = mean(ur_prod), by(sic4)
egen urt_avg = mean(ur_all), by(sic4)

noi disp "c4_avg"
_pctile c4_avg if year==1987, n(3)
gen c4low = c4_avg < r(r1)
gen c4high = c4_avg > r(r2)
noi return list

noi disp "urp_avg"
_pctile urp_avg if year==1987, n(3)
gen urlow = urp_avg < r(r1)
gen urhigh = urp_avg > r(r2)
noi return list

tsset sic4 year, y

******************************************************************************************
*** RESULTS
******************************************************************************************

***************
*** TABLE 1 ***
***************

** Industy-level
preserve
tempfile table1
egen nwp_avg = mean(nwp), by(year)
gen relnwp = 100*nwp/nwp_avg
egen relnwp_avg = mean(relnwp), by(sic4)
egen kHp_avg = mean(kHp), by(year)
gen relkHp = 100*kHp/kHp_avg
egen relkHp_avg = mean(relkHp), by(sic4)
drop if desc==""
duplicates drop sic4 theta_i, force
save `table1'
gsort -theta_i
format theta_i %04.3f
format *_avg %3.0f
noi list sic4 desc theta_i relkHp_avg relnwp_avg c4_avg urt_avg urp_avg in 1/25, clean comp

** All mfg, output weighted
use govindustry-v2.3.dta, replace
egen totvship = sum(vship), by(year)
gen wgtvship = vship/totvship
collapse (mean) wgtvship, by(sic4)
sort sic4
save wgtvship.dta, replace
use `table1', replace
merge sic4 using wgtvship.dta, sort
collapse (mean) theta_i relkHp_avg relnwp_avg c4_avg urp_avg urt_avg [iw=wgtvship]
format theta_i %04.3f
format *_avg %3.0f
noi disp _n "Weight: vship" _c
noi list theta_i relkHp_avg relnwp_avg c4_avg urp_avg urt_avg in 1, clean noobs
erase wgtvship.dta

** All mfg, government-spending weighted
use govindustry-v2.3.dta, replace
egen totgship = sum(gtotal), by(year)
gen wgtgship = gtotal/totgship
collapse (mean) wgtgship, by(sic4)
sort sic4
save wgtgship.dta, replace
use `table1', replace
merge sic4 using wgtgship.dta, sort
collapse (mean) theta_i relkHp_avg relnwp_avg c4_avg urp_avg urt_avg [iw=wgtgship]
format theta_i %04.3f
format *_avg %3.0f
noi disp _n "Weight: gtotal" _c
noi list theta_i relkHp_avg relnwp_avg c4_avg urp_avg urt_avg in 1, clean noobs
erase wgtgship.dta
restore
*/


***************
*** TABLE 2 ***
***************

*** COMPARISON OF INSTRUMENTS: 5-YEAR CHANGE
xi i.year
drop _Iyear_1961-_Iyear_1971 _Iyear_1973-_Iyear_1976 _Iyear_1983-_Iyear_1986 _Iyear_1978-_Iyear_1981 _Iyear_1983-_Iyear_1986 _Iyear_1988-_Iyear_1991 _Iyear_1993-_Iyear_2005

foreach var in d5rgper d5rgnum d5rgnumden d5rgnr1 d5rgnr2 d5rgnr3 {
  eststo `var'_y: xtreg d5ly `var' _I* if ioyear==1, fe
  eststo `var'_xpy: xtreg d5lxpy `var' _I* if ioyear==1, fe
}

*** COMPARISON OF INSTRUMENTS: ANNUAL CHANGE
char year[omit] 1960
xi i.year
drop _Iyear_1958-_Iyear_1959

foreach var in dgnr_std dgnr63_std {
  eststo `var'_y: xtreg dly `var' _I* if tin(1960,2005), fe
  eststo `var'_xpy: xtreg dlxpy `var' _I* if tin(1960,2005), fe
}

capture confirm file tab-inst.tex
if _rc==0 erase tab-inst.tex
noi esttab *_y, keep(d5rgper d5rgnum d5rgnumden d5rgnr1 d5rgnr2 d5rgnr3 dgnr_std dgnr63_std) unstack b(%04.3f) se star(* 0.10 ** 0.05 *** 0.01) comp
esttab *_y using tab-inst.tex, keep(d5rgper d5rgnum d5rgnumden d5rgnr1 d5rgnr2 d5rgnr3 dgnr_std dgnr63_std) b(%04.3f) se star(* 0.1 ** 0.05 *** 0.01) nodep nomti obslast nogaps unstack width(\textwidth) label booktabs alignment(d{1.3}) replace

noi esttab *_xpy, keep(d5rgper d5rgnum d5rgnumden d5rgnr1 d5rgnr2 d5rgnr3 dgnr_std dgnr63_std) unstack b(%04.3f) se star(* 0.10 ** 0.05 *** 0.01) compress
esttab *_xpy using tab-inst, keep(d5rgper d5rgnum d5rgnumden d5rgnr1 d5rgnr2 d5rgnr3 dgnr_std dgnr63_std) b(%04.3f) se star(* 0.1 ** 0.05 *** 0.01) nodep nomti obslast nogaps unstack width(\textwidth) label booktabs alignment(d{1.3}) append
*/


******************
*** TABLES 3-5 ***
******************
** REDUCED FORM REGRESSIONS
char year[omit] 1960
xi i.year

#delim cr
capture confirm file tab-rfreg.tex
if _rc==0 erase tab-rfreg.tex
foreach var in dlrvship dly dlHp dlxpy dlrwp dlnwp dlpiship dlNp dlhp dlk {
    noi disp as result _n _dup(80) "-"
    noi disp as input "DEPENDENT VARIABLE: `var'"
    eststo `var'0: xtreg `var' L.`var' dgnr _I* if tin(1960,2005), fe
    eststo `var'1: xtreg `var' L.`var' ldgnr _I* if tin(1960,2005), fe
    eststo `var'2: xtreg `var' L.`var' fdgnr _I* if tin(1960,2005), fe
    eststo `var'3: xtreg `var' L.`var' ldgnr dgnr fdgnr _I* if tin(1960,2005), fe
    noi esttab `var'0 `var'1 `var'2 `var'3, keep(L.`var' ldgnr dgnr fdgnr) order(L.`var' ldgnr dgnr fdgnr) b(%04.3f) se star(* 0.1 ** 0.05 *** 0.01) obslast nogaps
    esttab `var'0 `var'1 `var'2 `var'3 using tab-rfreg.tex, keep(L.`var' ldgnr dgnr fdgnr) order(L.`var' ldgnr dgnr fdgnr) b(%04.3f) se star(* 0.1 ** 0.05 *** 0.01) obslast nogaps unstack width(\textwidth) label booktabs alignment(d{2.4}) append
    noi esttab `var'0 `var'1 `var'2 `var'3, keep(ldgnr dgnr fdgnr) order(L.`var' ldgnr dgnr fdgnr) t(%04.3f) abs noobs nogaps
    noi test ldgnr dgnr fdgnr
    noi disp as result _dup(80) "-"
}
*/


***************
*** TABLE 6 ***
***************
* CONCENTRATION AND UNIONIZATION
char year[omit] 1960
xi i.year

foreach var in dly dgnr ldgnr fdgnr {
    * concentration interactions
    gen `var'_c4hi = `var'*c4high
    gen `var'_c4lo = `var'*c4low
    * unionization interactions
    gen `var'_urhi = `var'*urhigh
    gen `var'_urlo = `var'*urlow
}

eststo y_c4: xtreg dly L.dly dgnr dgnr_c4hi dgnr_c4lo _Iyear_1962-_Iyear_2005 if tin(1960,2005), fe
eststo y_ur: xtreg dly L.dly dgnr dgnr_urhi dgnr_urlo _Iyear_1962-_Iyear_2005 if tin(1960,2005), fe
eststo Hp_c4: xtreg dlHp L.dlHp dgnr dgnr_c4hi dgnr_c4lo _I* if tin(1960,2005), fe
eststo Hp_ur: xtreg dlHp L.dlHp dgnr dgnr_urhi dgnr_urlo _I* if tin(1960,2005), fe
eststo rwp_c4: xtreg dlrwp L.dlrwp ldgnr ldgnr_c4hi ldgnr_c4lo _I* if tin(1960,2005), fe
eststo rwp_ur: xtreg dlrwp L.dlrwp ldgnr ldgnr_urhi ldgnr_urlo _I* if tin(1960,2005), fe
eststo pi_c4: xtreg dlpiship L.dlpiship ldgnr ldgnr_c4hi ldgnr_c4lo _I* if tin(1960,2005), fe
eststo pi_ur: xtreg dlpiship L.dlpiship ldgnr ldgnr_urhi ldgnr_urlo _I* if tin(1960,2005), fe
eststo xpy_c4: xtreg dlxpy L.dlxpy ldgnr ldgnr_c4hi ldgnr_c4lo _I* if tin(1960,2005), fe
eststo xpy_ur: xtreg dlxpy L.dlxpy ldgnr ldgnr_urhi ldgnr_urlo _I* if tin(1960,2005), fe

noi esttab *c4, keep(L* *dgnr*) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L*)
noi esttab *ur, keep(L* *dgnr*) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L*)

** this block outputs the table to a tex file
est drop *c4 *ur
preserve
rename dly yvar
eststo y_c4: xtreg yvar L.yvar dgnr dgnr_c4hi dgnr_c4lo _Iyear_1962-_Iyear_2005 if tin(1960,2005), fe
eststo y_ur: xtreg yvar L.yvar dgnr dgnr_urhi dgnr_urlo _Iyear_1962-_Iyear_2005 if tin(1960,2005), fe
drop yvar
rename dlHp yvar
eststo Hp_c4: xtreg yvar L.yvar dgnr dgnr_c4hi dgnr_c4lo _I* if tin(1960,2005), fe
eststo Hp_ur: xtreg yvar L.yvar dgnr dgnr_urhi dgnr_urlo _I* if tin(1960,2005), fe
drop yvar
drop dgnr dgnr_urhi dgnr_urlo
rename ldgnr dgnr
rename ldgnr_urhi dgnr_urhi
rename ldgnr_urlo dgnr_urlo
rename dlrwp yvar
eststo rwp_c4: xtreg yvar L.yvar dgnr dgnr_c4hi dgnr_c4lo _I* if tin(1960,2005), fe
eststo rwp_ur: xtreg yvar L.yvar dgnr dgnr_urhi dgnr_urlo _I* if tin(1960,2005), fe
drop yvar
rename dlpiship yvar
eststo pi_c4: xtreg yvar L.yvar dgnr dgnr_c4hi dgnr_c4lo _I* if tin(1960,2005), fe
eststo pi_ur: xtreg yvar L.yvar dgnr dgnr_urhi dgnr_urlo _I* if tin(1960,2005), fe
drop yvar
rename dlxpy yvar
eststo xpy_c4: xtreg yvar L.yvar dgnr dgnr_c4hi dgnr_c4lo _I* if tin(1960,2005), fe
eststo xpy_ur: xtreg yvar L.yvar dgnr dgnr_urhi dgnr_urlo _I* if tin(1960,2005), fe
esttab *c4 using tab-c4ur.tex, keep(L* dgnr*) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L*) obslast nogaps unstack width(\textwidth) label booktabs alignment(d{1.3}) replace
esttab *ur using tab-c4ur.tex, keep(L* dgnr*) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L*) obslast nogaps unstack width(\textwidth) label booktabs alignment(d{1.3}) append
restore
*/


***************
*** TABLE 7 ***
***************
** REGRESSIONS WITH OTHER INPUTS
char year[omit] 1960
xi i.year

foreach var in dlHp dlNp dlhp dlNs dlk dlrmatxe dlrenergy {
    xtreg `var' L.`var' ldgnr dgnr fdgnr _I* if tin(1960,2005), fe
}

** this block outputs the table to a csv file to rotate by hand
preserve
foreach var in dlHp dlNp dlhp dlNs dlk dlrmatxe dlrenergy {
    rename `var' yvar
    eststo oi`var': xtreg yvar L.yvar ldgnr dgnr fdgnr _I* if tin(1960,2005), fe
    drop yvar
}
noi esttab oi*, keep(L* *dgnr) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L*) obslast nogaps comp
esttab oi* using tab-othinp.csv, keep(L* *dgnr) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L*) obslast nogaps replace
restore
*/


***************
*** TABLE 8 ***
***************
** IV REGRESSIONS WITH MARKUPS
* dpcm is the domowitz, hubbard, peterson markup
* the other markups are defined using output and production workers
char year[omit] 1960
xi i.year

* first-stage f-statistic
noi xtreg dly dgnr _I*, fe
noi xtreg dly dgnr ldgnr fdgnr _I*, fe
noi test (dgnr=0) (ldgnr=0) (fdgnr=0)

capture confirm file tab-markup.tex
if _rc==0 erase tab-markup.tex
foreach var in dlymup dlymumg50p dpcm {
    eststo `var'0: xtivreg `var' (dly = dgnr) _I*, fe
    eststo `var'1: xtivreg `var' (dly = dgnr ldgnr fdgnr) _I*, fe
    eststo `var'3: xtivreg `var' L.`var' (dly L.dly = dgnr ldgnr fdgnr) _I*, fe
    noi esttab `var'*, keep(L.* dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L.`var' L.dly dly)
    esttab `var'* using tab-markup.tex, keep(L.* dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01) order(L.`var' L.dly dly) obslast nogaps width(\textwidth) label booktabs alignment(d{2.4}) append
}
*/


***************
*** TABLE 9 ***
***************
** IV REGRESSIONS WITH SHARE WEIGHTED-INPUTS
char year[omit] 1960
xi i.year

* first-stage f-statistic
xtreg dlinput dgnr _I*, fe
xtreg dlinput dgnr ldgnr fdgnr _I*, fe
test ldgnr dgnr fdgnr

xtreg dlinput dgnr _I* if dur==1 & tin(1960,2005), fe
xtreg dlinput dgnr ldgnr fdgnr _I* if dur==1 & tin(1960,2005), fe
test ldgnr dgnr fdgnr

xtreg dlinput dgnr _I* if dur==0 & tin(1960,2005), fe
xtreg dlinput dgnr ldgnr fdgnr _I* if dur==0 & tin(1960,2005), fe
test ldgnr dgnr fdgnr


eststo rts1: xtreg dly dlinput _I* if tin(1960,2005), fe
test dlinput=1
eststo rts2: xtivreg dly (dlinput = dgnr ldgnr fdgnr) _I* if tin(1960,2005), fe
test dlinput=1
eststo rts3: xtreg dly dlinput dlhp _I* if tin(1960,2005), fe
test dlinput=1
eststo rts4: xtivreg dly (dlinput dlhp = dgnr ldgnr fdgnr) _I* if tin(1960,2005), fe
test dlinput=1

eststo rtsd1: xtreg dly dlinput _I* if dur==1 & tin(1960,2005), fe
test dlinput=1
eststo rtsd2: xtivreg dly (dlinput = dgnr ldgnr fdgnr) _I* if dur==1 & tin(1960,2005), fe
test dlinput=1
eststo rtsd3: xtreg dly dlinput dlhp _I* if dur==1 & tin(1960,2005), fe
test dlinput=1
eststo rtsd4: xtivreg dly (dlinput dlhp = dgnr ldgnr fdgnr) _I* if dur==1 & tin(1960,2005), fe
test dlinput=1

eststo rtsn1: xtreg dly dlinput _I* if dur==0 & tin(1960,2005), fe
test dlinput=1
eststo rtsn2: xtivreg dly (dlinput = dgnr ldgnr fdgnr) _I* if dur==0 & tin(1960,2005), fe
test dlinput=1
eststo rtsn3: xtreg dly dlinput dlhp _I* if dur==0 & tin(1960,2005), fe
test dlinput=1
eststo rtsn4: xtivreg dly (dlinput dlhp = dgnr ldgnr fdgnr) _I* if dur==0 & tin(1960,2005), fe
test dlinput=1

noi esttab rts?, keep(dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01)
noi esttab rtsd*, keep(dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01)
noi esttab rtsn*, keep(dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01)

capture erase tab-ivreg-rts.tex
esttab rts? using tab-ivreg-rts.tex, keep(dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01) obslast nogaps width(\textwidth) nolabel booktabs alignment(d{2.4})
esttab rtsd* using tab-ivreg-rts.tex, keep(dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01) obslast nogaps width(\textwidth) nolabel booktabs alignment(d{2.4}) append
esttab rtsn* using tab-ivreg-rts.tex, keep(dl*) b(%04.3f) se star(* 0.1 ** .05 *** .01) obslast nogaps width(\textwidth) nolabel booktabs alignment(d{2.4}) append
*/

capture log close
